@@ -80,16 +80,22 @@ class DataGeneratorBase(Sequence):
         self.reference_scores_df = self._transform_to_inchikey14(self.reference_scores_df)
         self._collect_and_validate_inchikeys()
         self.dim = dim
-        self.fixed_set = dict()
+        self.fixed_set = {}
 
     def _collect_and_validate_inchikeys(self):
         """Collect all inchikeys14 (first 14 characters) of all binned_spectrums
         and check if all are present in the reference scores as well.
+        Check for duplicate inchikeys.
         """
         self.spectrum_inchikeys = np.array([s.get("inchikey")[:14] for s in self.binned_spectrums])
         for inchikey in np.unique(self.spectrum_inchikeys):
             assert inchikey in self.reference_scores_df.index, \
                 "InChIKey in given spectrum not found in reference scores"
+        inchikeys = self.reference_scores_df.index
+        if len(set(inchikeys)) != len(inchikeys):
+            raise ValueError("Duplicate InChIKeys-14 detected in reference_scores_df: %s" % list(inchikeys[inchikeys.duplicated()]))
+
+
 
     @staticmethod
     def _validate_labels(reference_scores_df: pd.DataFrame):
@@ -159,7 +165,7 @@ class DataGeneratorBase(Sequence):
             ignore_equal_pairs=True,
             shuffle=True,
             same_prob_bins=[(0, 0.5), (0.5, 1)],
-            augment_removal_max= 0.3,
+            augment_removal_max=0.3,
             augment_removal_intensity=0.2,
             augment_intensity=0.4,
             augment_noise_max=10,
@@ -168,10 +174,9 @@ class DataGeneratorBase(Sequence):
         )
 
         # Set default parameters or replace by **settings input
-        for key in defaults:
+        for key, value in defaults.items():
             if key in settings:
-                print("The value for {} is set from {} (default) to {}".format(key, defaults[key],
-                                                                              settings[key]))
+                print(f"The value for {key} is set from {value} (default) to {settings[key]}")
             else:
                 settings[key] = defaults[key]
         assert 0.0 <= settings["augment_removal_max"] <= 1.0, "Expected value within [0,1]"
@@ -317,7 +322,7 @@ class DataGeneratorAllSpectrums(DataGeneratorBase):
             by inchikeys. Columns and index should be inchikeys, the value in a row x column
             depicting the similarity score for that pair. Must be symmetric
             (reference_scores_df[i,j] == reference_scores_df[j,i]) and column names should be
-            identical to the index.
+            identical to the index and unique.
         dim
             Input vector dimension.
         As part of **settings, defaults for the following parameters can be set:
@@ -461,7 +466,7 @@ class DataGeneratorAllInchikeys(DataGeneratorBase):
     def __len__(self):
         """Denotes the number of batches per epoch
         NB1: self.reference_scores_df only contains 'selected' inchikeys, see `self._data_selection`.
-        NB2: We don't see all data every epoch, because the last half-empty batch is omitted. 
+        NB2: We don't see all data every epoch, because the last half-empty batch is omitted.
         This is expected behavior, with the shuffling this is OK.
         """
         return int(self.settings["num_turns"]) * int(np.floor(len(self.reference_scores_df) / self.settings[
