@@ -1,7 +1,7 @@
 from pathlib import Path
 from typing import Union
 import h5py
-from tensorflow.python.keras.saving import hdf5_format
+from tensorflow import keras
 
 from ms2deepscore.SpectrumBinner import SpectrumBinner
 from .SiameseModel import SiameseModel
@@ -26,7 +26,7 @@ def load_model(filename: Union[str, Path]) -> SiameseModel:
     """
     with h5py.File(filename, mode='r') as f:
         binner_json = f.attrs['spectrum_binner']
-        keras_model = hdf5_format.load_model_from_hdf5(f)
+        keras_model = keras.models.load_model(f)
 
     spectrum_binner = SpectrumBinner.from_json(binner_json)
     return SiameseModel(spectrum_binner, keras_model=keras_model)
